==> ideaIU-144.4199.23.zip: com/intellij/psi/css/descriptor/BrowserVersion.java <==
package com.intellij.psi.css.descriptor;

import com.intellij.icons.AllIcons;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;
import java.util.Comparator;

/**
 * User: zolotov
 * Date: 3/13/13
 */
public class BrowserVersion {
  public static final BrowserVersion[] EMPTY_ARRAY = new BrowserVersion[0];
  public static final Comparator<BrowserVersion> COMPARATOR = new Comparator<BrowserVersion>() {
    @Override
    public int compare(@NotNull BrowserVersion o1, @NotNull BrowserVersion o2) {
      return o1.getBrowser().getPresentableName().compareTo(o2.getBrowser().getPresentableName());
    }
  };
  
  @NotNull private final Browser myBrowser;
  @NotNull private final String myVersion;

  public BrowserVersion(@NotNull Browser browser, @NotNull String version) {
    myBrowser = browser;
    myVersion = version;
  }

  @NotNull
  @Override
  public String toString() {
    return myBrowser.getPresentableName() + ' ' + myVersion;
  }

  @NotNull
  public String getVersion() {
    return myVersion;
  }

  @NotNull
  public Browser getBrowser() {
    return myBrowser;
  }

  @NotNull
  public static BrowserVersion fromString(@NotNull String string) {
    if (!string.isEmpty()) {
      switch (string.charAt(0)) {
        case 'C':
          return new BrowserVersion(Browser.CHROME, string.substring(1));
        case 'F': //FF expected
          return new BrowserVersion(Browser.FIREFOX, string.substring(2));
        case 'I': //IE expected
          return new BrowserVersion(Browser.IE, string.substring(2));
        case 'O':
          return new BrowserVersion(Browser.OPERA, string.substring(1));
        case 'S':
          return new BrowserVersion(Browser.SAFARI, string.substring(1));
        case 'E':
          return new BrowserVersion(Browser.EDGE, string.substring(1));
      }
    }
    throw new IllegalArgumentException("Can't create browser version for " + string);
  }

  public enum Browser {
    CHROME("Chrome", AllIcons.Xml.Browsers.Chrome16),
    FIREFOX("Firefox", AllIcons.Xml.Browsers.Firefox16),
    SAFARI("Safari", AllIcons.Xml.Browsers.Safari16),
    OPERA("Opera", AllIcons.Xml.Browsers.Opera16),
    IE("IE", AllIcons.Xml.Browsers.Explorer16),
    EDGE("MS Edge", AllIcons.Xml.Browsers.Edge16);

    @NotNull private final Icon myIcon;
    @NotNull private final String myPresentableName;

    Browser(@NotNull String presentableName, @NotNull Icon icon) {
      myIcon = icon;
      myPresentableName = presentableName;
    }

    @NotNull
    public Icon getIcon() {
      return myIcon;
    }

    @NotNull
    public String getPresentableName() {
      return myPresentableName;
    }
  }

}

==> ideaIU-171.4694.15.zip: com/intellij/psi/css/descriptor/BrowserVersion.java <==
package com.intellij.psi.css.descriptor;

import com.intellij.icons.AllIcons;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;
import java.util.Comparator;

/**
 * User: zolotov
 * Date: 3/13/13
 */
public class BrowserVersion {
  public static final BrowserVersion[] EMPTY_ARRAY = new BrowserVersion[0];
  public static final Comparator<BrowserVersion> COMPARATOR =
    (o1, o2) -> o1.getBrowser().getPresentableName().compareTo(o2.getBrowser().getPresentableName());
  
  @NotNull private final Browser myBrowser;
  @NotNull private final String myVersion;

  public BrowserVersion(@NotNull Browser browser, @NotNull String version) {
    myBrowser = browser;
    myVersion = version;
  }

  @NotNull
  @Override
  public String toString() {
    return myBrowser.getPresentableName() + ' ' + myVersion;
  }

  @NotNull
  public String getVersion() {
    return myVersion;
  }

  @NotNull
  public Browser getBrowser() {
    return myBrowser;
  }

  @NotNull
  public static BrowserVersion fromString(@NotNull String string) {
    if (!string.isEmpty()) {
      switch (string.charAt(0)) {
        case 'C':
          return new BrowserVersion(Browser.CHROME, string.substring(1));
        case 'F': //FF expected
          return new BrowserVersion(Browser.FIREFOX, string.substring(2));
        case 'I': //IE expected
          return new BrowserVersion(Browser.IE, string.substring(2));
        case 'O':
          return new BrowserVersion(Browser.OPERA, string.substring(1));
        case 'S':
          return new BrowserVersion(Browser.SAFARI, string.substring(1));
        case 'E':
          return new BrowserVersion(Browser.EDGE, string.substring(1));
      }
    }
    throw new IllegalArgumentException("Can't create browser version for " + string);
  }

  public enum Browser {
    CHROME("Chrome", AllIcons.Xml.Browsers.Chrome16),
    FIREFOX("Firefox", AllIcons.Xml.Browsers.Firefox16),
    SAFARI("Safari", AllIcons.Xml.Browsers.Safari16),
    OPERA("Opera", AllIcons.Xml.Browsers.Opera16),
    IE("IE", AllIcons.Xml.Browsers.Explorer16),
    EDGE("MS Edge", AllIcons.Xml.Browsers.Edge16);

    @NotNull private final Icon myIcon;
    @NotNull private final String myPresentableName;

    Browser(@NotNull String presentableName, @NotNull Icon icon) {
      myIcon = icon;
      myPresentableName = presentableName;
    }

    @NotNull
    public Icon getIcon() {
      return myIcon;
    }

    @NotNull
    public String getPresentableName() {
      return myPresentableName;
    }
  }

}
